#!/usr/bin/python3
# coding: utf-8

# To be able to run this import out of django, you'll have to set an environment variable with the Echosciences token:
# export ECHOSCIENCES_TOKEN=<your token>

import json
import os
import sys

# getting the name of the directory
# where the this file is present.
current = os.path.dirname(os.path.realpath(__file__))

# Getting the parent directory name
# where the current directory is present.
parent = os.path.dirname(current)

# adding the parent directory to
# the sys.path.
sys.path.append(parent)
sys.path.append(parent + "/src")

from src.agenda_culturel.import_tasks.downloader import SimpleDownloader
from src.agenda_culturel.import_tasks.generic_extractors.echosciences import (
    CExtractor,
)
from src.agenda_culturel.import_tasks.importer import URL2Events


if __name__ == "__main__":
    u2e = URL2Events(SimpleDownloader(), CExtractor())
    url = "https://www.echosciences-auvergne.fr"
    url_human = "https://www.echosciences-auvergne.fr"

    events = u2e.process(
        url,
        url_human,
        cache="cache-echosciences.html",
        default_values={},
        published=True,
    )

    exportfile = "events-echosciences.json"
    print("Saving events to file {}".format(exportfile))
    with open(exportfile, "w") as f:
        json.dump(events, f, indent=4, default=str)
